==> cscec5b-wzxt-api-3.0.0-20210323.091033-178-sources.jar: com/ejianc/business/wzxt/vo/ExitApplyGFVO.java <==
package com.ejianc.business.wzxt.vo;

import java.util.ArrayList;
import java.util.List;

/**
 * 退场申请单推送供方vo
 *
 * @Author songlx
 * @Date 2021-03-20
 **/
public class ExitApplyGFVO {
    private static final long serialVersionUID = 1L;

    private Long id;
    private String billCode; // 单据编号
    private String projectId; // 项目
    private String projectName; // 项目名称
    private String orgId; // 组织
    private String orgName; // 组织名称
    private String contractId; // 合同主键
    private String contractName; // 合同名称
    private String contractCode; // 合同编号
    private String supplierId; // 设备供应商
    private String supplierName; // 供应商名称
    private String exitDate; // 退场日期
    private String exitDesc; // 退场说明
    private String sceneurl;//现场照片url（逗号隔开）例如：group1/M00/03/ED/rB7JfGBAizCAIVS_AAD6Jjikza4607.jpg
    private String czsignurl;//承租方签字url（逗号隔开）
    private String jlsingurl;//租赁房签字url（逗号隔开）
    private List<ExitApplyDetailGFVO> exitApplyDetail = new ArrayList<>(); // 退场单明细

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    public String getProjectId() {
        return projectId;
    }

    public void setProjectId(String projectId) {
        this.projectId = projectId;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public String getOrgId() {
        return orgId;
    }

    public void setOrgId(String orgId) {
        this.orgId = orgId;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public String getContractId() {
        return contractId;
    }

    public void setContractId(String contractId) {
        this.contractId = contractId;
    }

    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }

    public String getContractCode() {
        return contractCode;
    }

    public void setContractCode(String contractCode) {
        this.contractCode = contractCode;
    }

    public String getSupplierId() {
        return supplierId;
    }

    public void setSupplierId(String supplierId) {
        this.supplierId = supplierId;
    }

    public String getSupplierName() {
        return supplierName;
    }

    public void setSupplierName(String supplierName) {
        this.supplierName = supplierName;
    }

    public String getExitDate() {
        return exitDate;
    }

    public void setExitDate(String exitDate) {
        this.exitDate = exitDate;
    }

    public String getExitDesc() {
        return exitDesc;
    }

    public void setExitDesc(String exitDesc) {
        this.exitDesc = exitDesc;
    }

    public String getSceneurl() {
        return sceneurl;
    }

    public void setSceneurl(String sceneurl) {
        this.sceneurl = sceneurl;
    }

    public String getCzsignurl() {
        return czsignurl;
    }

    public void setCzsignurl(String czsignurl) {
        this.czsignurl = czsignurl;
    }

    public String getJlsingurl() {
        return jlsingurl;
    }

    public void setJlsingurl(String jlsingurl) {
        this.jlsingurl = jlsingurl;
    }

    public List<ExitApplyDetailGFVO> getExitApplyDetail() {
        return exitApplyDetail;
    }

    public void setExitApplyDetail(List<ExitApplyDetailGFVO> exitApplyDetail) {
        this.exitApplyDetail = exitApplyDetail;
    }
}

==> cscec5b-wzxt-api-3.0.0-20210323.102159-184-sources.jar: com/ejianc/business/wzxt/vo/ExitApplyGFVO.java <==
package com.ejianc.business.wzxt.vo;

import java.util.ArrayList;
import java.util.List;

/**
 * 退场申请单推送供方vo
 *
 * @Author songlx
 * @Date 2021-03-20
 **/
public class ExitApplyGFVO {
    private static final long serialVersionUID = 1L;

    private Long id;
    private String billCode; // 单据编号
    private String projectId; // 项目
    private String projectName; // 项目名称
    private String orgId; // 组织
    private String orgName; // 组织名称
    private String contractId; // 合同主键
    private String contractName; // 合同名称
    private String contractCode; // 合同编号
    private String supplierId; // 设备供应商
    private String supplierName; // 供应商名称
    private String exitDate; // 退场日期
    private String exitDesc; // 退场说明
    private String sceneurl;//现场照片url（逗号隔开）例如：group1/M00/03/ED/rB7JfGBAizCAIVS_AAD6Jjikza4607.jpg
    private String czsignurl;//承租方签字url（逗号隔开）
    private String jlsingurl;//租赁房签字url（逗号隔开）
    private String confirmFlag;
    private List<ExitApplyDetailGFVO> exitApplyDetail = new ArrayList<>(); // 退场单明细

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    public String getProjectId() {
        return projectId;
    }

    public void setProjectId(String projectId) {
        this.projectId = projectId;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public String getOrgId() {
        return orgId;
    }

    public void setOrgId(String orgId) {
        this.orgId = orgId;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public String getContractId() {
        return contractId;
    }

    public void setContractId(String contractId) {
        this.contractId = contractId;
    }

    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }

    public String getContractCode() {
        return contractCode;
    }

    public void setContractCode(String contractCode) {
        this.contractCode = contractCode;
    }

    public String getSupplierId() {
        return supplierId;
    }

    public void setSupplierId(String supplierId) {
        this.supplierId = supplierId;
    }

    public String getSupplierName() {
        return supplierName;
    }

    public void setSupplierName(String supplierName) {
        this.supplierName = supplierName;
    }

    public String getExitDate() {
        return exitDate;
    }

    public void setExitDate(String exitDate) {
        this.exitDate = exitDate;
    }

    public String getExitDesc() {
        return exitDesc;
    }

    public void setExitDesc(String exitDesc) {
        this.exitDesc = exitDesc;
    }

    public String getSceneurl() {
        return sceneurl;
    }

    public void setSceneurl(String sceneurl) {
        this.sceneurl = sceneurl;
    }

    public String getCzsignurl() {
        return czsignurl;
    }

    public void setCzsignurl(String czsignurl) {
        this.czsignurl = czsignurl;
    }

    public String getJlsingurl() {
        return jlsingurl;
    }

    public void setJlsingurl(String jlsingurl) {
        this.jlsingurl = jlsingurl;
    }

    public String getConfirmFlag() {
        return confirmFlag;
    }

    public void setConfirmFlag(String confirmFlag) {
        this.confirmFlag = confirmFlag;
    }

    public List<ExitApplyDetailGFVO> getExitApplyDetail() {
        return exitApplyDetail;
    }

    public void setExitApplyDetail(List<ExitApplyDetailGFVO> exitApplyDetail) {
        this.exitApplyDetail = exitApplyDetail;
    }
}
